@@ -9,7 +9,8 @@ def bundle_mathlive(sender, **kwargs):
 
 
 class BaseConfig(AppConfig):
-    name = 'base'
+    name = "base"
+    default_auto_field = "django.db.models.AutoField"
 
     def ready(self):
         post_npm_install.connect(bundle_mathlive)
