@@ -50,6 +50,8 @@ PASSWORD_LOGIN = True
 # Whether anyone surfing to the site can open an account or login with a
 # socialaccount.
 SOCIALACCOUNT_OPEN = True
+SOCIALACCOUNT_STORE_TOKENS = True
+SOCIALACCOUNT_EMAIL_VERIFICATION = "none"
 
 # This determines whether there is a star labeled "Free" on the login page
 IS_FREE = True
@@ -228,6 +230,7 @@ AUTHENTICATION_BACKENDS = (
 )
 
 TEST_RUNNER = "django.test.runner.DiscoverRunner"
+TESTING = False  # Overriden by test runner.
 
 
 # Define available languages
