@@ -15,18 +15,18 @@ export class AdminConsole {
 
     bind() {
         this.ws = new WebSocketConnector({
-            url: '/ws/base/',
+            url: "/ws/base/",
             appLoaded: () => true,
-            initialMessage: () => ({type: 'subscribe_admin'}),
+            initialMessage: () => ({type: "subscribe_admin"}),
             receiveData: data => {
                 switch (data.type) {
-                case 'connection_info':
+                case "connection_info":
                     this.renderConnectionInfo(data.sessions)
                     break
-                case 'message_delivered': {
-                    addAlert('info', gettext('Message delivered successfully!'))
-                    const button = document.querySelector('input#submit_user_message')
-                    button.value = gettext('Message delivered')
+                case "message_delivered": {
+                    addAlert("info", gettext("Message delivered successfully!"))
+                    const button = document.querySelector("input#submit_user_message")
+                    button.value = gettext("Message delivered")
                     break
                 }
                 default:
@@ -36,17 +36,17 @@ export class AdminConsole {
 
         })
         this.ws.init()
-        document.body.addEventListener('click', event => {
+        document.body.addEventListener("click", event => {
             const el = {}
             switch (true) {
-            case findTarget(event, 'input#submit_user_message:not(.disabled)', el): {
-                const message = document.querySelector('textarea#user_message').value
+            case findTarget(event, "input#submit_user_message:not(.disabled)", el): {
+                const message = document.querySelector("textarea#user_message").value
                 if (!message.length) {
                     return
                 }
-                document.querySelector('textarea#user_message').disabled = true
-                document.querySelector('input#submit_user_message').disabled = true
-                document.querySelector('input#submit_user_message').value = gettext('Sending...')
+                document.querySelector("textarea#user_message").disabled = true
+                document.querySelector("input#submit_user_message").disabled = true
+                document.querySelector("input#submit_user_message").value = gettext("Sending...")
                 this.sendUserMessage(message)
                 break
             }
@@ -57,11 +57,11 @@ export class AdminConsole {
     }
 
     sendUserMessage(message) {
-        this.ws.send(() => ({type: 'message', message}))
+        this.ws.send(() => ({type: "message", message}))
     }
 
     renderConnectionInfo(sessions) {
-        const counterEl = document.getElementById('session_count')
+        const counterEl = document.getElementById("session_count")
         if (counterEl) {
             counterEl.innerHTML = sessions
         }
