@@ -20,6 +20,11 @@ export {
 }
     from "./basic"
 
+export {
+    convertDataURIToBlob
+}
+    from "./blob"
+
 export {
     get,
     getJson,
