@@ -3,12 +3,12 @@ import {PreloginPage} from "../prelogin"
 export class SetupPage extends PreloginPage {
     constructor({app, language}) {
         super({app, language})
-        this.title = gettext('Update')
+        this.title = gettext("Update")
         this.contents = `<div class="fw-login-left">
-            <h1 class="fw-login-title">${gettext('Update')}</h1>
+            <h1 class="fw-login-title">${gettext("Update")}</h1>
             <p>${interpolate(
         gettext(
-            'The %(appName)s server is currently being updated. Please wait.'
+            "The %(appName)s server is currently being updated. Please wait."
         ),
         {appName: this.app.name},
         true
@@ -23,7 +23,7 @@ export class SetupPage extends PreloginPage {
     init() {
         setTimeout(() => this.app.init(), 5000)
         return super.init().then(
-            () => document.querySelectorAll('#lang-selection,.feedback-tab').forEach(el => el.style.visibility = 'hidden')
+            () => document.querySelectorAll("#lang-selection,.feedback-tab").forEach(el => el.style.visibility = "hidden")
         )
     }
 }
