@@ -8,15 +8,15 @@ export function extractTemplate(doc) {
     template.content = template.content.filter(part => !part.attrs || !part.attrs.deleted)
     template.content.forEach(part => {
         delete part.content
-        if (part.type === 'title') {
+        if (part.type === "title") {
             delete part.attrs
             return
         } else if (part.attrs.initial) {
             part.content = JSON.parse(JSON.stringify(part.attrs.initial))
-        } else if (['heading_part', 'richtext_part'].includes(part.type)) {
+        } else if (["heading_part", "richtext_part"].includes(part.type)) {
             part.content = [{type: part.attrs.elements[0]}]
-        } else if (part.type === 'table') {
-            part.content = [{type: 'table', content: [{type: 'table_row', content: [{type: 'table_cell', content: [{type: 'paragraph'}]}]}]}]
+        } else if (part.type === "table") {
+            part.content = [{type: "table", content: [{type: "table_row", content: [{type: "table_cell", content: [{type: "paragraph"}]}]}]}]
         }
         delete part.attrs.deleted
         if (!part.attrs.help) {
@@ -35,7 +35,7 @@ export function extractTemplate(doc) {
             delete part.attrs.metadata
         }
         delete part.attrs.hidden
-        if (part.attrs.optional === 'hidden') {
+        if (part.attrs.optional === "hidden") {
             part.attrs.hidden = true
         }
         if (!part.attrs.optional) {
