@@ -11,19 +11,19 @@ copyCitation.toDOM = function(node) {
         bibs = {}
     node.attrs.references.forEach(ref => bibs[ref.id] = bibDB.db[ref.id])
     return ["span", {
-        class: 'citation',
-        'data-format': node.attrs.format,
-        'data-references': JSON.stringify(node.attrs.references),
-        'data-bibs': JSON.stringify(bibs)
+        class: "citation",
+        "data-format": node.attrs.format,
+        "data-references": JSON.stringify(node.attrs.references),
+        "data-bibs": JSON.stringify(bibs)
     }]
 }
 
 export const createDocCopySchema = docSchema => new Schema({
     marks: docSchema.spec.marks,
-    nodes: docSchema.spec.nodes.update('citation', copyCitation)
+    nodes: docSchema.spec.nodes.update("citation", copyCitation)
 })
 
 export const fnCopySchema = new Schema({
     marks: fnSchema.spec.marks,
-    nodes: fnSchema.spec.nodes.update('citation', copyCitation)
+    nodes: fnSchema.spec.nodes.update("citation", copyCitation)
 })
