@@ -10,8 +10,8 @@ export class ModFootnoteLayout {
 
     init() {
         // Add two elements to hold dynamic CSS info about comments.
-        const styleContainers = document.createElement('temp')
-        styleContainers.innerHTML = `<style type="text/css" id="footnote-placement-style"></style>`
+        const styleContainers = document.createElement("temp")
+        styleContainers.innerHTML = "<style type=\"text/css\" id=\"footnote-placement-style\"></style>"
         while (styleContainers.firstElementChild) {
             document.body.appendChild(styleContainers.firstElementChild)
         }
@@ -22,36 +22,36 @@ export class ModFootnoteLayout {
         // DOM write phase - nothing to do.
         fastdom.measure(() => {
             // DOM read phase
-            const footnoteBoxes = document.querySelectorAll('#footnote-box-container .footnote-container'),
+            const footnoteBoxes = document.querySelectorAll("#footnote-box-container .footnote-container"),
                 referrers = getFootnoteMarkers(this.mod.editor.view.state)
             if (
-                (!referrers.length && this.mod.editor.mod.citations.citationType !== 'note') ||
+                (!referrers.length && this.mod.editor.mod.citations.citationType !== "note") ||
                 referrers.length !== footnoteBoxes.length
             ) {
                 // Apparently not all footnote boxes have been drawn or there are none. Abort for now.
                 return
             }
-            const footnoteBoxContainer = document.getElementById('footnote-box-container')
-            let footnotePlacementStyle = ''
+            const footnoteBoxContainer = document.getElementById("footnote-box-container")
+            let footnotePlacementStyle = ""
 
-            if (getComputedStyle(footnoteBoxContainer).display === 'block') {
+            if (getComputedStyle(footnoteBoxContainer).display === "block") {
                 // We are in mobile/tablet mode. We don't need to place footnotes.
-            } else if (this.mod.editor.mod.citations.citationType === 'note') {
+            } else if (this.mod.editor.mod.citations.citationType === "note") {
                 const totalOffset = footnoteBoxContainer.getBoundingClientRect().top
                 /* Citations are also in footnotes, so both citation footnotes
                  * and editor footnotes have to be placed. They should be placed
                  * in the order the markers appear in the content, even though
                  * editor footnotes and citations footnotes are separated in the DOM.
                 */
-                const citationFootnotes = document.querySelectorAll('#citation-footnote-box-container .footnote-citation')
+                const citationFootnotes = document.querySelectorAll("#citation-footnote-box-container .footnote-citation")
                 let editorFootnoteIndex = 0,
                     citationFootnoteIndex = 0,
                     totalEditorOffset = totalOffset,
                     totalCitationOffset = totalOffset
                 this.mod.editor.view.state.doc.descendants((node, pos) => {
-                    if (node.isInline && (node.type.name === 'footnote' || node.type.name === 'citation')) {
+                    if (node.isInline && (node.type.name === "footnote" || node.type.name === "citation")) {
                         let topMargin = 10
-                        if (node.type.name === 'footnote') {
+                        if (node.type.name === "footnote") {
                             const footnoteBox = footnoteBoxes[editorFootnoteIndex],
                                 selector = `.footnote-container:nth-of-type(${(editorFootnoteIndex + 1)})`,
                                 footnoteBoxCoords = footnoteBox.getBoundingClientRect(),
@@ -71,7 +71,7 @@ export class ModFootnoteLayout {
                         } else {
                             if (citationFootnotes.length > citationFootnoteIndex) {
                                 const footnoteBox = citationFootnotes[citationFootnoteIndex],
-                                    selector = '.footnote-citation:nth-of-type(' + (citationFootnoteIndex + 1) + ')',
+                                    selector = ".footnote-citation:nth-of-type(" + (citationFootnoteIndex + 1) + ")",
                                     footnoteBoxCoords = footnoteBox.getBoundingClientRect(),
                                     footnoteBoxHeight = footnoteBoxCoords.height,
                                     referrerTop = this.mod.editor.view.coordsAtPos(pos).top
@@ -125,8 +125,8 @@ export class ModFootnoteLayout {
 
             fastdom.mutate(() => {
                 //DOM write phase
-                if (document.getElementById('footnote-placement-style').innerHTML != footnotePlacementStyle) {
-                    document.getElementById('footnote-placement-style').innerHTML = footnotePlacementStyle
+                if (document.getElementById("footnote-placement-style").innerHTML != footnotePlacementStyle) {
+                    document.getElementById("footnote-placement-style").innerHTML = footnotePlacementStyle
                 }
             })
 
