@@ -8,14 +8,14 @@ import {WordCountDialog, KeyBindingsDialog, SearchReplaceDialog} from "../../too
 const languageItem = function(code, name, order) {
     return {
         title: name,
-        type: 'setting',
+        type: "setting",
         order,
         action: editor => {
             const article = editor.view.state.doc.firstChild
             const attrs = Object.assign({}, article.attrs)
             attrs.language = code
             editor.view.dispatch(
-                editor.view.state.tr.setNodeMarkup(0, false, attrs).setMeta('settings', true)
+                editor.view.state.tr.setNodeMarkup(0, false, attrs).setMeta("settings", true)
             )
         },
         selected: editor => {
@@ -32,17 +32,17 @@ export const headerbarModel = () => ({
     open: window.innerWidth > 500, // Whether the menu is shown at all.
     content: [
         {
-            id: 'file',
-            title: gettext('File'),
-            tooltip: gettext('File handling'),
-            type: 'menu',
+            id: "file",
+            title: gettext("File"),
+            tooltip: gettext("File handling"),
+            type: "menu",
             order: 0,
             content: [
                 {
-                    title: gettext('Share'),
-                    type: 'action',
+                    title: gettext("Share"),
+                    type: "action",
                     //icon: 'share',
-                    tooltip: gettext('Share the document with other users.'),
+                    tooltip: gettext("Share the document with other users."),
                     order: 0,
                     action: editor => {
                         const dialog = new DocumentAccessRightsDialog(
@@ -59,18 +59,18 @@ export const headerbarModel = () => ({
                     }
                 },
                 {
-                    title: gettext('Close'),
-                    type: 'action',
+                    title: gettext("Close"),
+                    type: "action",
                     //icon: 'times-circle',
-                    tooltip: gettext('Close the document and return to the document overview menu.'),
+                    tooltip: gettext("Close the document and return to the document overview menu."),
                     order: 1,
                     action: editor => {
                         const folderPath = editor.docInfo.path.slice(
                             0,
-                            editor.docInfo.path.lastIndexOf('/')
+                            editor.docInfo.path.lastIndexOf("/")
                         )
-                        if (!folderPath.length) {
-                            editor.app.goTo('/')
+                        if (!folderPath.length && editor.app.routes[""].app === "document") {
+                            editor.app.goTo("/")
                         } else {
                             editor.app.goTo(`/documents${folderPath}/`)
                         }
@@ -78,12 +78,12 @@ export const headerbarModel = () => ({
                     disabled: editor => editor.app.isOffline()
                 },
                 {
-                    title: gettext('Save revision'),
-                    type: 'action',
+                    title: gettext("Save revision"),
+                    type: "action",
                     //icon: 'save',
-                    tooltip: gettext('Save a revision of the document.'),
+                    tooltip: gettext("Save a revision of the document."),
                     order: 2,
-                    keys: 'Ctrl-s',
+                    keys: "Ctrl-s",
                     action: editor => {
                         const dialog = new RevisionDialog(editor.docInfo.dir)
                         dialog.init().then(
@@ -99,13 +99,13 @@ export const headerbarModel = () => ({
                             }
                         )
                     },
-                    disabled: editor => editor.docInfo.access_rights !== 'write' || editor.app.isOffline()
+                    disabled: editor => editor.docInfo.access_rights !== "write" || editor.app.isOffline()
                 },
                 {
-                    title: gettext('Create copy'),
-                    type: 'action',
+                    title: gettext("Create copy"),
+                    type: "action",
                     //icon: 'copy',
-                    tooltip: gettext('Create a copy of the document.'),
+                    tooltip: gettext("Create a copy of the document."),
                     order: 3,
                     action: editor => {
                         const copier = new SaveCopy(
@@ -121,10 +121,10 @@ export const headerbarModel = () => ({
                     disabled: editor => editor.app.isOffline(),
                 },
                 {
-                    title: gettext('Download'),
-                    type: 'action',
+                    title: gettext("Download"),
+                    type: "action",
                     //icon: 'download',
-                    tooltip: gettext('Export the document as a FIDUS file including its template.'),
+                    tooltip: gettext("Export the document as a FIDUS file including its template."),
                     order: 4,
                     action: editor => {
                         new ExportFidusFile(
@@ -136,19 +136,19 @@ export const headerbarModel = () => ({
                     disabled: editor => editor.app.isOffline(),
                 },
                 {
-                    title: gettext('Print/PDF'),
-                    type: 'action',
+                    title: gettext("Print/PDF"),
+                    type: "action",
                     //icon: 'print',
-                    tooltip: gettext('Either print or create a PDF using your browser print dialog.'),
+                    tooltip: gettext("Either print or create a PDF using your browser print dialog."),
                     order: 5,
-                    keys: 'Ctrl-p',
+                    keys: "Ctrl-p",
                     action: editor => {
                         import("../../../exporter/print").then(({PrintExporter}) => {
                             const exporter = new PrintExporter(
                                 editor.schema,
                                 editor.app.csl,
                                 editor.mod.documentTemplate.documentStyles,
-                                editor.getDoc({changes: 'acceptAllNoInsertions'}),
+                                editor.getDoc({changes: "acceptAllNoInsertions"}),
                                 editor.mod.db.bibDB,
                                 editor.mod.db.imageDB
                             )
@@ -159,16 +159,16 @@ export const headerbarModel = () => ({
             ]
         },
         {
-            id: 'export',
-            title: gettext('Export'),
-            tooltip: gettext('Export of the document contents'),
-            type: 'menu',
+            id: "export",
+            title: gettext("Export"),
+            tooltip: gettext("Export of the document contents"),
+            type: "menu",
             order: 1,
             content: [
                 {
-                    title: gettext('HTML'),
-                    type: 'action',
-                    tooltip: gettext('Export the document to an HTML file.'),
+                    title: gettext("HTML (old)"),
+                    type: "action",
+                    tooltip: gettext("Export the document to an HTML file."),
                     order: 0,
                     action: editor => {
                         import("../../../exporter/html").then(({HTMLExporter}) => {
@@ -176,7 +176,7 @@ export const headerbarModel = () => ({
                                 editor.schema,
                                 editor.app.csl,
                                 editor.mod.documentTemplate.documentStyles,
-                                editor.getDoc({changes: 'acceptAllNoInsertions'}),
+                                editor.getDoc({changes: "acceptAllNoInsertions"}),
                                 editor.mod.db.bibDB,
                                 editor.mod.db.imageDB,
                                 editor.docInfo.updated
@@ -186,9 +186,28 @@ export const headerbarModel = () => ({
                     }
                 },
                 {
-                    title: gettext('Epub'),
-                    type: 'action',
-                    tooltip: gettext('Export the document to an Epub electronic reader file.'),
+                    title: gettext("HTML (new)"),
+                    type: "action",
+                    tooltip: gettext("Export the document to an HTML file."),
+                    order: 0.5,
+                    action: editor => {
+                        import("../../../exporter/html2").then(({HTMLExporter}) => {
+                            const exporter = new HTMLExporter(
+                                editor.getDoc({changes: "acceptAllNoInsertions"}),
+                                editor.mod.db.bibDB,
+                                editor.mod.db.imageDB,
+                                editor.app.csl,
+                                editor.docInfo.updated,
+                                editor.mod.documentTemplate.documentStyles
+                            )
+                            exporter.init()
+                        })
+                    }
+                },
+                {
+                    title: gettext("Epub"),
+                    type: "action",
+                    tooltip: gettext("Export the document to an Epub electronic reader file."),
                     order: 1,
                     action: editor => {
                         import("../../../exporter/epub").then(({EpubExporter}) => {
@@ -196,7 +215,7 @@ export const headerbarModel = () => ({
                                 editor.schema,
                                 editor.app.csl,
                                 editor.mod.documentTemplate.documentStyles,
-                                editor.getDoc({changes: 'acceptAllNoInsertions'}),
+                                editor.getDoc({changes: "acceptAllNoInsertions"}),
                                 editor.mod.db.bibDB,
                                 editor.mod.db.imageDB,
                                 editor.docInfo.updated
@@ -207,14 +226,14 @@ export const headerbarModel = () => ({
                     disabled: editor => editor.app.isOffline()
                 },
                 {
-                    title: gettext('LaTeX'),
-                    type: 'action',
-                    tooltip: gettext('Export the document to an LaTeX file.'),
+                    title: gettext("LaTeX"),
+                    type: "action",
+                    tooltip: gettext("Export the document to an LaTeX file."),
                     order: 2,
                     action: editor => {
                         import("../../../exporter/latex").then(({LatexExporter}) => {
                             const exporter = new LatexExporter(
-                                editor.getDoc({changes: 'acceptAllNoInsertions'}),
+                                editor.getDoc({changes: "acceptAllNoInsertions"}),
                                 editor.mod.db.bibDB,
                                 editor.mod.db.imageDB,
                                 editor.docInfo.updated
@@ -225,14 +244,14 @@ export const headerbarModel = () => ({
                     disabled: editor => editor.app.isOffline()
                 },
                 {
-                    title: gettext('JATS'),
-                    type: 'action',
-                    tooltip: gettext('Export the document to a Journal Archiving and Interchange Tag Library NISO JATS Version 1.2 file.'),
+                    title: gettext("JATS"),
+                    type: "action",
+                    tooltip: gettext("Export the document to a Journal Archiving and Interchange Tag Library NISO JATS Version 1.2 file."),
                     order: 2,
                     action: editor => {
                         import("../../../exporter/jats").then(({JATSExporter}) => {
                             const exporter = new JATSExporter(
-                                editor.getDoc({changes: 'acceptAllNoInsertions'}),
+                                editor.getDoc({changes: "acceptAllNoInsertions"}),
                                 editor.mod.db.bibDB,
                                 editor.mod.db.imageDB,
                                 editor.app.csl,
@@ -244,9 +263,9 @@ export const headerbarModel = () => ({
                     disabled: editor => editor.app.isOffline()
                 },
                 {
-                    title: gettext('Slim FIDUS'),
-                    type: 'action',
-                    tooltip: gettext('Export the document to a FIDUS file without its template.'),
+                    title: gettext("Slim FIDUS"),
+                    type: "action",
+                    tooltip: gettext("Export the document to a FIDUS file without its template."),
                     order: 3,
                     action: editor => {
                         new ExportFidusFile(
@@ -260,99 +279,99 @@ export const headerbarModel = () => ({
             ]
         },
         {
-            id: 'settings',
-            title: gettext('Settings'),
-            tooltip: gettext('Configure settings of this document.'),
-            type: 'menu',
+            id: "settings",
+            title: gettext("Settings"),
+            tooltip: gettext("Configure settings of this document."),
+            type: "menu",
             order: 2,
             content: [
                 {
-                    id: 'citation_style',
-                    title: gettext('Citation Style'),
-                    type: 'menu',
-                    tooltip: gettext('Choose your preferred citation style.'),
+                    id: "citation_style",
+                    title: gettext("Citation Style"),
+                    type: "menu",
+                    tooltip: gettext("Choose your preferred citation style."),
                     order: 1,
                     disabled: editor => {
-                        return editor.docInfo.access_rights !== 'write'
+                        return editor.docInfo.access_rights !== "write"
                     },
                     content: []
                 },
                 {
-                    id: 'document_style',
-                    title: gettext('Document Style'),
-                    type: 'menu',
-                    tooltip: gettext('Choose your preferred document style.'),
+                    id: "document_style",
+                    title: gettext("Document Style"),
+                    type: "menu",
+                    tooltip: gettext("Choose your preferred document style."),
                     order: 2,
                     disabled: editor => {
-                        return editor.docInfo.access_rights !== 'write' || editor.app.isOffline()
+                        return editor.docInfo.access_rights !== "write" || editor.app.isOffline()
                     },
                     content: []
                 },
                 {
-                    id: 'language',
-                    title: gettext('Text Language'),
-                    type: 'menu',
-                    tooltip: gettext('Choose the language of the document.'),
+                    id: "language",
+                    title: gettext("Text Language"),
+                    type: "menu",
+                    tooltip: gettext("Choose the language of the document."),
                     order: 3,
                     disabled: editor => {
-                        return editor.docInfo.access_rights !== 'write'
+                        return editor.docInfo.access_rights !== "write"
                     },
                     content: [
-                        languageItem('en-US', gettext('English (United States)'), 0),
-                        languageItem('en-GB', gettext('English (United Kingdom)'), 1),
-                        languageItem('de-DE', gettext('German (Germany)'), 2),
-                        languageItem('zh-CN', gettext('Chinese (Simplified)'), 3),
-                        languageItem('es', gettext('Spanish'), 4),
-                        languageItem('fr', gettext('French'), 5),
-                        languageItem('ja', gettext('Japanese'), 6),
-                        languageItem('it', gettext('Italian'), 7),
+                        languageItem("en-US", gettext("English (United States)"), 0),
+                        languageItem("en-GB", gettext("English (United Kingdom)"), 1),
+                        languageItem("de-DE", gettext("German (Germany)"), 2),
+                        languageItem("zh-CN", gettext("Chinese (Simplified)"), 3),
+                        languageItem("es", gettext("Spanish"), 4),
+                        languageItem("fr", gettext("French"), 5),
+                        languageItem("ja", gettext("Japanese"), 6),
+                        languageItem("it", gettext("Italian"), 7),
                         //languageItem('pl', gettext('Polish'), 8),
-                        languageItem('pt-BR', gettext('Portuguese (Brazil)'), 9),
+                        languageItem("pt-BR", gettext("Portuguese (Brazil)"), 9),
                         //languageItem('nl', gettext('Dutch'), 10),
                         //languageItem('ru', gettext('Russian'), 11),
                         {
-                            type: 'separator',
+                            type: "separator",
                             order: 12,
                             available: editor => {
                                 // There has to be at least one language of the default languages
                                 // among the default ones and one that is not among the default ones.
                                 return !!editor.view.state.doc.firstChild.attrs.languages.find(
                                     lang => [
-                                        'en-US',
-                                        'en-GB',
-                                        'de-DE',
-                                        'zh-CN',
-                                        'es',
-                                        'fr',
-                                        'ja',
-                                        'it',
-                                        'pl',
-                                        'pt-BR',
-                                        'nl',
-                                        'ru'
+                                        "en-US",
+                                        "en-GB",
+                                        "de-DE",
+                                        "zh-CN",
+                                        "es",
+                                        "fr",
+                                        "ja",
+                                        "it",
+                                        "pl",
+                                        "pt-BR",
+                                        "nl",
+                                        "ru"
                                     ].includes(lang)
                                 ) && !!editor.view.state.doc.firstChild.attrs.languages.find(
                                     lang => ![
-                                        'en-US',
-                                        'en-GB',
-                                        'de-DE',
-                                        'zh-CN',
-                                        'es',
-                                        'fr',
-                                        'ja',
-                                        'it',
-                                        'pl',
-                                        'pt-BR',
-                                        'nl',
-                                        'ru'
+                                        "en-US",
+                                        "en-GB",
+                                        "de-DE",
+                                        "zh-CN",
+                                        "es",
+                                        "fr",
+                                        "ja",
+                                        "it",
+                                        "pl",
+                                        "pt-BR",
+                                        "nl",
+                                        "ru"
                                     ].includes(lang)
                                 )
 
                             }
                         },
                         {
-                            title: gettext('Other'),
-                            type: 'setting',
+                            title: gettext("Other"),
+                            type: "setting",
                             order: 13,
                             action: editor => {
                                 const language = editor.view.state.doc.firstChild.attrs.language,
@@ -361,96 +380,96 @@ export const headerbarModel = () => ({
                             },
                             selected: editor => {
                                 return ![
-                                    'en-US',
-                                    'en-GB',
-                                    'de-DE',
-                                    'zh-CN',
-                                    'es',
-                                    'fr',
-                                    'ja',
-                                    'it',
-                                    'pl',
-                                    'pt-BR',
-                                    'nl',
-                                    'ru'
+                                    "en-US",
+                                    "en-GB",
+                                    "de-DE",
+                                    "zh-CN",
+                                    "es",
+                                    "fr",
+                                    "ja",
+                                    "it",
+                                    "pl",
+                                    "pt-BR",
+                                    "nl",
+                                    "ru"
                                 ].includes(
                                     editor.view.state.doc.firstChild.attrs.language
                                 )
                             },
                             available: editor => !!editor.view.state.doc.firstChild.attrs.languages.find(
                                 lang => ![
-                                    'en-US',
-                                    'en-GB',
-                                    'de-DE',
-                                    'zh-CN',
-                                    'es',
-                                    'fr',
-                                    'ja',
-                                    'it',
-                                    'pl',
-                                    'pt-BR',
-                                    'nl',
-                                    'ru'
+                                    "en-US",
+                                    "en-GB",
+                                    "de-DE",
+                                    "zh-CN",
+                                    "es",
+                                    "fr",
+                                    "ja",
+                                    "it",
+                                    "pl",
+                                    "pt-BR",
+                                    "nl",
+                                    "ru"
                                 ].includes(lang)
                             )
                         }
                     ]
                 },
                 {
-                    id: 'paper_size',
-                    title: gettext('Paper Size'),
-                    type: 'menu',
-                    tooltip: gettext('Choose a papersize for print and PDF generation.'),
+                    id: "paper_size",
+                    title: gettext("Paper Size"),
+                    type: "menu",
+                    tooltip: gettext("Choose a papersize for print and PDF generation."),
                     order: 4,
                     disabled: editor => {
-                        return editor.docInfo.access_rights !== 'write'
+                        return editor.docInfo.access_rights !== "write"
                     },
                     content: [
                         {
-                            title: gettext('DIN A4'),
-                            type: 'setting',
-                            tooltip: gettext('A4 (DIN A4/ISO 216) which is used in most of the world.'),
+                            title: gettext("DIN A4"),
+                            type: "setting",
+                            tooltip: gettext("A4 (DIN A4/ISO 216) which is used in most of the world."),
                             order: 0,
                             action: editor => {
                                 const article = editor.view.state.doc.firstChild
                                 const attrs = Object.assign({}, article.attrs)
-                                attrs.papersize = 'A4'
+                                attrs.papersize = "A4"
                                 editor.view.dispatch(
-                                    editor.view.state.tr.setNodeMarkup(0, false, attrs).setMeta('settings', true)
+                                    editor.view.state.tr.setNodeMarkup(0, false, attrs).setMeta("settings", true)
                                 )
                             },
                             selected: editor => {
-                                return editor.view.state.doc.firstChild.attrs.papersize === 'A4'
+                                return editor.view.state.doc.firstChild.attrs.papersize === "A4"
                             },
                             available: editor => {
-                                return editor.view.state.doc.firstChild.attrs.papersizes.includes('A4')
+                                return editor.view.state.doc.firstChild.attrs.papersizes.includes("A4")
                             }
                         },
                         {
-                            title: gettext('US Letter'),
-                            type: 'setting',
-                            tooltip: gettext('The format used by the USA and some other American countries.'),
+                            title: gettext("US Letter"),
+                            type: "setting",
+                            tooltip: gettext("The format used by the USA and some other American countries."),
                             order: 1,
                             action: editor => {
                                 const article = editor.view.state.doc.firstChild
                                 const attrs = Object.assign({}, article.attrs)
-                                attrs.papersize = 'US Letter'
+                                attrs.papersize = "US Letter"
                                 editor.view.dispatch(
-                                    editor.view.state.tr.setNodeMarkup(0, false, attrs).setMeta('settings', true)
+                                    editor.view.state.tr.setNodeMarkup(0, false, attrs).setMeta("settings", true)
                                 )
                             },
                             selected: editor => {
-                                return editor.view.state.doc.firstChild.attrs.papersize === 'US Letter'
+                                return editor.view.state.doc.firstChild.attrs.papersize === "US Letter"
                             },
                             available: editor => {
-                                return editor.view.state.doc.firstChild.attrs.papersizes.includes('US Letter')
+                                return editor.view.state.doc.firstChild.attrs.papersizes.includes("US Letter")
                             }
                         }
                     ]
                 },
                 {
-                    title: gettext('Copyright Information'),
-                    type: 'setting',
+                    title: gettext("Copyright Information"),
+                    type: "setting",
                     order: 5,
                     action: editor => {
                         const dialog = new CopyrightDialog(editor.view.state.doc.firstChild.attrs.copyright)
@@ -461,28 +480,28 @@ export const headerbarModel = () => ({
                                     const attrs = Object.assign({}, article.attrs, {copyright})
 
                                     editor.view.dispatch(
-                                        editor.view.state.tr.setNodeMarkup(0, false, attrs).setMeta('settings', true)
+                                        editor.view.state.tr.setNodeMarkup(0, false, attrs).setMeta("settings", true)
                                     )
                                 }
                                 editor.currentView.focus()
                             }
                         )
                     },
-                    disabled: editor => editor.docInfo.access_rights !== 'write'
+                    disabled: editor => editor.docInfo.access_rights !== "write"
                 }
             ]
         },
         {
-            id: 'tools',
-            title: gettext('Tools'),
-            tooltip: gettext('Select document editing tool.'),
-            type: 'menu',
+            id: "tools",
+            title: gettext("Tools"),
+            tooltip: gettext("Select document editing tool."),
+            type: "menu",
             order: 3,
             content: [
                 {
-                    title: gettext('Word counter'),
-                    type: 'action',
-                    tooltip: gettext('See document statistics.'),
+                    title: gettext("Word counter"),
+                    type: "action",
+                    tooltip: gettext("See document statistics."),
                     order: 0,
                     action: editor => {
                         const dialog = new WordCountDialog(editor)
@@ -490,22 +509,22 @@ export const headerbarModel = () => ({
                     }
                 },
                 {
-                    title: gettext('Search and replace'),
-                    type: 'action',
-                    tooltip: gettext('Show a search and replace dialog.'),
+                    title: gettext("Search and replace"),
+                    type: "action",
+                    tooltip: gettext("Show a search and replace dialog."),
                     order: 1,
-                    keys: 'Ctrl-h',
+                    keys: "Ctrl-h",
                     action: editor => {
                         const dialog = new SearchReplaceDialog(editor)
                         dialog.init()
                     }
                 },
                 {
-                    title: gettext('Keyboard shortcuts'),
-                    type: 'action',
-                    tooltip: gettext('Show an overview of available keyboard shortcuts.'),
+                    title: gettext("Keyboard shortcuts"),
+                    type: "action",
+                    tooltip: gettext("Show an overview of available keyboard shortcuts."),
                     order: 2,
-                    keys: 'Shift-Ctrl-/',
+                    keys: "Shift-Ctrl-/",
                     action: editor => {
                         const dialog = new KeyBindingsDialog(editor)
                         dialog.init()
@@ -514,26 +533,26 @@ export const headerbarModel = () => ({
             ]
         },
         {
-            title: gettext('Track changes'),
-            type: 'menu',
-            tooltip: gettext('Tracking changes to the document'),
+            title: gettext("Track changes"),
+            type: "menu",
+            tooltip: gettext("Tracking changes to the document"),
             order: 4,
-            disabled: editor => editor.docInfo.access_rights !== 'write',
+            disabled: editor => editor.docInfo.access_rights !== "write",
             content: [
                 {
-                    title: gettext('Record'),
-                    type: 'setting',
-                    tooltip: gettext('Record document changes'),
+                    title: gettext("Record"),
+                    type: "setting",
+                    tooltip: gettext("Record document changes"),
                     order: 0,
                     disabled: editor => {
-                        return editor.docInfo.access_rights !== 'write'
+                        return editor.docInfo.access_rights !== "write"
                     },
                     action: editor => {
                         const article = editor.view.state.doc.firstChild
                         const attrs = Object.assign({}, article.attrs)
                         attrs.tracked = !attrs.tracked
                         editor.view.dispatch(
-                            editor.view.state.tr.setNodeMarkup(0, false, attrs).setMeta('settings', true)
+                            editor.view.state.tr.setNodeMarkup(0, false, attrs).setMeta("settings", true)
                         )
                     },
                     selected: editor => {
@@ -541,18 +560,18 @@ export const headerbarModel = () => ({
                     }
                 },
                 {
-                    title: gettext('Accept all'),
-                    type: 'action',
-                    tooltip: gettext('Accept all tracked changes.'),
+                    title: gettext("Accept all"),
+                    type: "action",
+                    tooltip: gettext("Accept all tracked changes."),
                     order: 1,
                     action: editor => {
                         editor.mod.track.acceptAll()
                     }
                 },
                 {
-                    title: gettext('Reject all'),
-                    type: 'action',
-                    tooltip: gettext('Reject all tracked changes.'),
+                    title: gettext("Reject all"),
+                    type: "action",
+                    tooltip: gettext("Reject all tracked changes."),
                     order: 2,
                     action: editor => {
                         editor.mod.track.rejectAll()
