@@ -2,7 +2,7 @@ import {Plugin, PluginKey} from "prosemirror-state"
 
 import {HeaderbarView} from "../menus"
 
-const key = new PluginKey('header')
+const key = new PluginKey("header")
 export const headerbarPlugin = function(options) {
     return new Plugin({
         key,
