@@ -56,7 +56,9 @@ export class DocxExporterCitations {
             this.citInfos,
             this.exporter.doc.settings.citationstyle,
             "",
-            this.bibDB
+            this.bibDB,
+            false,
+            this.exporter.doc.settings.language
         )
         return this.citFm.init().then(
             () => {
