@@ -1,5 +1,6 @@
 import {get} from "../../common"
 import {descendantNodes} from "../tools/doc_content"
+import {svg2png} from "../tools/svg"
 
 export class DocxExporterImages {
     constructor(exporter, imageDB, rels, docContent) {
@@ -7,7 +8,7 @@ export class DocxExporterImages {
         this.imageDB = imageDB
         this.rels = rels
         this.docContent = docContent
-        this.imgIdTranslation = {}
+        this.images = {}
         this.ctXml = false
     }
 
@@ -61,11 +62,32 @@ export class DocxExporterImages {
                         response => response.blob()
                     ).then(
                         blob => {
-                            const wImgId = this.addImage(
-                                imgDBEntry.image.split("/").pop(),
-                                blob
-                            )
-                            this.imgIdTranslation[image] = wImgId
+                            if (blob.type === "image/svg+xml") {
+                                // DOCX doesn't support SVG. Convert to PNG.
+                                return svg2png(blob).then(({blob: pngBlob, width, height}) => {
+                                    const wImgId = this.addImage(
+                                        imgDBEntry.image.split("/").pop().replace(/.svg$/g, ".png"),
+                                        pngBlob
+                                    )
+                                    this.images[image] = {
+                                        id: wImgId,
+                                        width,
+                                        height,
+                                        title: imgDBEntry.title
+                                    }
+                                })
+                            } else {
+                                const wImgId = this.addImage(
+                                    imgDBEntry.image.split("/").pop(),
+                                    blob
+                                )
+                                this.images[image] = {
+                                    id: wImgId,
+                                    width: imgDBEntry.width,
+                                    height: imgDBEntry.height,
+                                    title: imgDBEntry.title
+                                }
+                            }
                         }
                     )
                 )
