@@ -9,13 +9,13 @@ export const opfTemplate = ({id, idType, title, language, authors, keywords, dat
         <dc:identifier id="${idType}">${id}</dc:identifier>
             <dc:title>${escapeText(title)}</dc:title>
 ${
-    authors.map(author => `\t\t<dc:creator>${escapeText(author)}</dc:creator>\n`).join('')
+    authors.map(author => `\t\t<dc:creator>${escapeText(author)}</dc:creator>\n`).join("")
 }${
-    keywords.map(keyword => `\t\t<dc:subject>${escapeText(keyword)}</dc:subject>\n`).join('')
+    keywords.map(keyword => `\t\t<dc:subject>${escapeText(keyword)}</dc:subject>\n`).join("")
 }
         <dc:language>${language}</dc:language>
         <dc:date>${date}</dc:date>
-        ${ copyright && copyright.holder ? `<dc:rights>© ${ copyright.year ? copyright.year : new Date().getFullYear()} ${escapeText(copyright.holder)}</dc:rights>` : ''}
+        ${ copyright && copyright.holder ? `<dc:rights>© ${ copyright.year ? copyright.year : new Date().getFullYear()} ${escapeText(copyright.holder)}</dc:rights>` : ""}
         <meta property="dcterms:modified">${modified}</meta>
     </metadata>
     <manifest>
@@ -25,18 +25,18 @@ ${
     images.map((image, index) =>
         `\t\t\t<item ${
             image.coverImage ?
-                'id="cover-image" properties="cover-image"' :
+                "id=\"cover-image\" properties=\"cover-image\"" :
                 `id="img${index}"`
         } href="${
             image.filename
         }" media-type="image/${
             image.filename.split(".")[1] === "png" ?
-                'png' :
+                "png" :
                 image.filename.split(".")[1] === "svg" ?
-                    'svg+xml' :
-                    'jpeg'
+                    "svg+xml" :
+                    "jpeg"
         }" />\n`
-    ).join('')
+    ).join("")
 }${
     fontFiles.map((fontFile, index) =>
         `\t\t\t<item ${
@@ -45,20 +45,20 @@ ${
             fontFile.filename
         }" media-type="font/${
             fontFile.filename.split(".")[1] === "woff" ?
-                'woff' :
+                "woff" :
                 fontFile.filename.split(".")[1] === "woff2" ?
-                    'woff2' :
-                    'sfnt'
+                    "woff2" :
+                    "sfnt"
         }" />\n`
-    ).join('')
+    ).join("")
 }${
     styleSheets.map((sheet, index) =>
         `\t\t\t<item id="css${index}" href="${sheet.filename}" media-type="text/css" />\n`
-    ).join('')
+    ).join("")
 }${
     math ?
         mathliveOpfIncludes :
-        ''
+        ""
 }
         <!-- ncx included for 2.0 reading system compatibility: -->
         <item id="ncx" href="document.ncx" media-type="application/x-dtbncx+xml" />
@@ -93,7 +93,7 @@ export const ncxTemplate = ({shortLang, idType, id, title, contentItems}) =>
 ${
     contentItems.map(item =>
         ncxItemTemplate({item})
-    ).join('')
+    ).join("")
 }
     </navMap>
 </ncx>`
@@ -106,7 +106,7 @@ export const ncxItemTemplate = ({item}) =>
 ${
     item.subItems.map(
         item => ncxItemTemplate({item})
-    ).join('')
+    ).join("")
 }
         </navPoint>\n`
 
@@ -117,58 +117,39 @@ export const xhtmlTemplate = ({shortLang, title, math, styleSheets, part, curren
 <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="${shortLang}" lang="${shortLang}"
         xmlns:epub="http://www.idpf.org/2007/ops">
     <head>
-        ${copyright && copyright.holder ? `<meta name="copyright" content="© ${copyright.year ? copyright.year : new Date().getFullYear()} ${escapeText(copyright.holder)}" />` : ''}
+        ${copyright && copyright.holder ? `<meta name="copyright" content="© ${copyright.year ? copyright.year : new Date().getFullYear()} ${escapeText(copyright.holder)}" />` : ""}
         <title>${escapeText(title)}</title>
 ${
     math ?
-        '<link rel="stylesheet" type="text/css" href="css/mathlive.css" />\n' :
-        ''
+        "<link rel=\"stylesheet\" type=\"text/css\" href=\"css/mathlive.css\" />\n" :
+        ""
 }
 ${
     styleSheets.map(sheet => `<link rel="stylesheet" type="text/css" href="${sheet.filename}" />\n`
-    ).join('')
+    ).join("")
 }
     </head>
-    <body${currentPart && currentPart.length ? ` class="${currentPart.toLowerCase().replace(/[^a-z]/g, '')}"` : ''}>${
+    <body class="${currentPart && currentPart.length ? `epub ${currentPart.toLowerCase().replace(/[^a-z]/g, "")} content` : "epub content"}"${currentPart && currentPart.length ? ` data-part="${escapeText(currentPart)}"` : ""} data-title="${escapeText(title)}">${
     part && part.length ?
         `<h1 class="part">${escapeText(part)}</h1>` :
-        ''
+        ""
 }${
     body
 }${
     copyright && copyright.holder ?
         `<div>© ${copyright.year ? copyright.year : new Date().getFullYear()} ${copyright.holder}</div>` :
-        ''
+        ""
 }
     ${
     copyright && copyright.licenses.length ?
-        `<div>${copyright.licenses.map(license => `<a rel="license" href="${escapeText(license.url)}">${escapeText(license.title)}${license.start ? ` (${license.start})` : ''}</a>`).join('</div><div>')}</div>` :
-        ''
+        `<div>${copyright.licenses.map(license => `<a rel="license" href="${escapeText(license.url)}">${escapeText(license.title)}${license.start ? ` (${license.start})` : ""}</a>`).join("</div><div>")}</div>` :
+        ""
 }</body>
 </html>`
 
 
-/** A template for an epub's navigation document. */
-export const navTemplate = ({shortLang, contentItems}) =>
-    `<?xml version="1.0" encoding="UTF-8"?>
-<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="${shortLang}" lang="${shortLang}" xmlns:epub="http://www.idpf.org/2007/ops">
-    <head>
-        <meta charset="utf-8"></meta>
-        <title>Navigation</title>
-    </head>
-    <body>
-        <nav epub:type="toc" id="toc">
-            <ol>
-${
-    contentItems.map(item => navItemTemplate({item})).join('')
-}
-            </ol>
-        </nav>
-    </body>
-</html>`
-
 /** A template for each item in an epub's navigation document. */
-export const navItemTemplate = ({item}) =>
+const navItemTemplate = ({item}) =>
     `\t\t\t\t<li><a href="${
         item.link ?
             item.link :
@@ -182,9 +163,33 @@ ${
         ${
     item.subItems.map(item =>
         navItemTemplate({item})
-    ).join('')
+    ).join("")
 }
     </ol>` :
-        ''
+        ""
 }
 </li>`
+
+
+/** A template for an epub's navigation document. */
+export const navTemplate = ({shortLang, contentItems, styleSheets}) =>
+    `<?xml version="1.0" encoding="UTF-8"?>
+<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="${shortLang}" lang="${shortLang}" xmlns:epub="http://www.idpf.org/2007/ops">
+    <head>
+        <meta charset="utf-8"></meta>
+        <title>Navigation</title>
+        ${
+    styleSheets.map(sheet => `<link rel="stylesheet" type="text/css" href="${sheet.filename}" />\n`
+    ).join("")
+}
+    </head>
+    <body class="epub navigation">
+        <nav epub:type="toc" id="toc">
+            <ol>
+${
+    contentItems.map(item => navItemTemplate({item})).join("")
+}
+            </ol>
+        </nav>
+    </body>
+</html>`
