@@ -2,6 +2,7 @@ import {escapeText} from "../../common"
 import {CATS} from "../../schema/i18n"
 
 import {articleTemplate} from "./templates"
+import {convertText} from "./text"
 
 export class JATSExporterConvert {
     constructor(exporter, imageDB, bibDB, settings) {
@@ -53,22 +54,22 @@ export class JATSExporterConvert {
     // Remove items from the body that should be in the front.
     preWalkJson(node, parentNode = false) {
         switch (node.type) {
-        case 'article':
+        case "article":
             this.frontMatter.copyright = node.attrs.copyright
             break
-        case 'title':
-            this.frontMatter.title['default'] = node
+        case "title":
+            this.frontMatter.title["default"] = node
             parentNode.content = parentNode.content.filter(child => child !== node)
             break
-        case 'heading_part':
+        case "heading_part":
             if (
-                ['title', 'subtitle'].includes(node.attrs.metadata) &&
-                    !this.frontMatter[node.attrs.metadata][node.attrs.language || 'default'] &&
+                ["title", "subtitle"].includes(node.attrs.metadata) &&
+                    !this.frontMatter[node.attrs.metadata][node.attrs.language || "default"] &&
                     node.content &&
                     node.content.length
             ) {
                 // We only take the first instance of title/subtitle per language
-                this.frontMatter[node.attrs.metadata][node.attrs.language || 'default'] = {
+                this.frontMatter[node.attrs.metadata][node.attrs.language || "default"] = {
                     type: node.attrs.language ? `trans_${node.attrs.metadata}` : node.attrs.metadata,
                     attrs: {
                         id: node.content[0].attrs.id,
@@ -79,14 +80,14 @@ export class JATSExporterConvert {
                 parentNode.content = parentNode.content.filter(child => child !== node)
             }
             break
-        case 'richtext_part':
+        case "richtext_part":
             if (
-                node.attrs.metadata === 'abstract' &&
-                    !this.frontMatter.abstract[node.attrs.language || 'default']
+                node.attrs.metadata === "abstract" &&
+                    !this.frontMatter.abstract[node.attrs.language || "default"]
             ) {
                 // We only take the first instance of abstract per language
-                this.frontMatter.abstract[node.attrs.language || 'default'] = {
-                    type: node.attrs.language ? 'trans_abstract' : 'abstract',
+                this.frontMatter.abstract[node.attrs.language || "default"] = {
+                    type: node.attrs.language ? "trans_abstract" : "abstract",
                     attrs: {
                         id: node.attrs.id,
                         language: node.attrs.language
@@ -96,12 +97,13 @@ export class JATSExporterConvert {
                 parentNode.content = parentNode.content.filter(child => child !== node)
             }
             break
-        case 'tags_part':
+        case "tags_part":
             if (
-                node.attrs.metadata === 'keywords'
+                node.attrs.metadata === "keywords" &&
+                node.content
             ) {
                 this.frontMatter.keywords.push({
-                    type: 'keywords',
+                    type: "keywords",
                     attrs: {
                         language: node.attrs.language
                     },
@@ -112,7 +114,7 @@ export class JATSExporterConvert {
             }
             parentNode.content = parentNode.content.filter(child => child !== node)
             break
-        case 'contributors_part':
+        case "contributors_part":
             this.frontMatter.contributors.push(node)
             parentNode.content = parentNode.content.filter(child => child !== node)
             break
@@ -130,7 +132,7 @@ export class JATSExporterConvert {
         if (this.frontMatter.subtitle.default) {
             this.findCitations(this.frontMatter.subtitle.default)
         }
-        Object.keys(this.frontMatter.title).filter(language => language !== 'default').forEach(language => {
+        Object.keys(this.frontMatter.title).filter(language => language !== "default").forEach(language => {
             this.findCitations(this.frontMatter.title[language])
             if (this.frontMatter.subtitle[language]) {
                 this.findCitations(this.frontMatter.subtitle[language])
@@ -139,7 +141,7 @@ export class JATSExporterConvert {
         if (this.frontMatter.abstract.default) {
             this.findCitations(this.frontMatter.abstract.default)
         }
-        Object.keys(this.frontMatter.abstract).filter(language => language !== 'default').forEach(language => {
+        Object.keys(this.frontMatter.abstract).filter(language => language !== "default").forEach(language => {
             this.findCitations(this.frontMatter.abstract[language])
         })
         this.findCitations(docContent)
@@ -147,10 +149,10 @@ export class JATSExporterConvert {
 
     findCitations(node) {
         switch (node.type) {
-        case 'citation':
+        case "citation":
             this.citInfos.push(JSON.parse(JSON.stringify(node.attrs)))
             break
-        case 'footnote':
+        case "footnote":
             node.attrs.footnote.forEach(child => this.findCitations(child))
             break
         default:
@@ -162,120 +164,120 @@ export class JATSExporterConvert {
     }
 
     assembleFront() {
-        let front = '<front><article-meta>'
+        let front = "<front><article-meta>"
         if (this.frontMatter.tags.length) {
-            front += `<article-categories>${this.frontMatter.tags.map(node => this.walkJson(node)).join('')}</article-categories>`
+            front += `<article-categories>${this.frontMatter.tags.map(node => this.walkJson(node)).join("")}</article-categories>`
         }
-        Object.keys(this.frontMatter.subtitle).filter(language => language !== 'default').forEach(language => {
+        Object.keys(this.frontMatter.subtitle).filter(language => language !== "default").forEach(language => {
             // Making sure there is a title for each subtitle
             if (!this.frontMatter.title[language]) {
-                this.frontMatter.title[language] = {type: 'trans_title', attrs: {language}}
+                this.frontMatter.title[language] = {type: "trans_title", attrs: {language}}
             }
         })
-        front += '<title-group>'
+        front += "<title-group>"
         front += this.walkJson(this.frontMatter.title.default)
         if (this.frontMatter.subtitle.default) {
             front += this.walkJson(this.frontMatter.subtitle.default)
         }
-        Object.keys(this.frontMatter.title).filter(language => language !== 'default').forEach(language => {
+        Object.keys(this.frontMatter.title).filter(language => language !== "default").forEach(language => {
             front += `<trans-title-group @xml:lang="${language}">`
             front += this.walkJson(this.frontMatter.title[language])
             if (this.frontMatter.subtitle[language]) {
                 front += this.walkJson(this.frontMatter.subtitle[language])
             }
-            front += '</trans-title-group>'
+            front += "</trans-title-group>"
         })
-        front += '</title-group>'
+        front += "</title-group>"
         this.frontMatter.contributors.forEach(contributors => {
             front += this.walkJson(contributors)
         })
         Object.entries(this.affiliations).forEach(([institution, index]) => front += `<aff id="aff${index}"><institution>${escapeText(institution)}</institution></aff>`)
         // https://validator.jats4r.org/ requires a <permissions> element here, but is OK with it being empty.
         if (this.frontMatter.copyright.holder) {
-            front += '<permissions>'
+            front += "<permissions>"
             const year = this.frontMatter.copyright.year ? this.frontMatter.copyright.year : new Date().getFullYear()
             front += `<copyright-year>${year}</copyright-year>`
             front += `<copyright-holder>${escapeText(this.frontMatter.copyright.holder)}</copyright-holder>`
             if (this.frontMatter.copyright.freeToRead) {
-                front += '<ali:free_to_read/>'
+                front += "<ali:free_to_read/>"
             }
             front += this.frontMatter.copyright.licenses.map(license =>
-                `<license><ali:license_ref${license.start ? ` start_date="${license.start}"` : ''}>${escapeText(license.url)}</ali:license_ref></license>`
-            ).join('')
-            front += '</permissions>'
+                `<license><ali:license_ref${license.start ? ` start_date="${license.start}"` : ""}>${escapeText(license.url)}</ali:license_ref></license>`
+            ).join("")
+            front += "</permissions>"
         } else {
-            front += '<permissions/>'
+            front += "<permissions/>"
         }
         if (this.frontMatter.abstract.default) {
             front += this.walkJson(this.frontMatter.abstract.default)
             front += this.closeSections(0)
         }
-        Object.keys(this.frontMatter.abstract).filter(language => language !== 'default').forEach(language => {
+        Object.keys(this.frontMatter.abstract).filter(language => language !== "default").forEach(language => {
             front += this.walkJson(this.frontMatter.abstract[language])
             front += this.closeSections(0)
         })
         this.frontMatter.keywords.forEach(keywords => {
             front += this.walkJson(keywords)
         })
-        front += '</article-meta></front>'
+        front += "</article-meta></front>"
         return front
     }
 
 
     walkJson(node, options = {}) {
-        let start = '', content = '', end = ''
+        let start = "", content = "", end = ""
         switch (node.type) {
-        case 'article':
+        case "article":
             break
-        case 'title':
-            start += '<article-title>'
-            end = '</article-title>' + end
+        case "title":
+            start += "<article-title>"
+            end = "</article-title>" + end
             break
-        case 'trans_title':
-            start += '<trans-title>'
-            end = '</trans-title>' + end
+        case "trans_title":
+            start += "<trans-title>"
+            end = "</trans-title>" + end
             break
-        case 'subtitle':
+        case "subtitle":
             if (node.content) {
-                start += '<subtitle>'
-                end = '</subtitle>' + end
+                start += "<subtitle>"
+                end = "</subtitle>" + end
             }
             break
-        case 'trans_subtitle':
+        case "trans_subtitle":
             if (node.content) {
-                start += '<trans-subtitle>'
-                end = '</trans-subtitle>' + end
+                start += "<trans-subtitle>"
+                end = "</trans-subtitle>" + end
             }
             break
-        case 'heading_part':
+        case "heading_part":
             // Ignore - we deal with the heading inside
             break
-        case 'contributor':
+        case "contributor":
             // Ignore - we deal with contributors_part instead.
             break
-        case 'contributors_part':
+        case "contributors_part":
             if (node.content) {
                 const contributorTypes = {
-                    authors: 'author',
-                    editors: 'editor'
+                    authors: "author",
+                    editors: "editor"
                 }
-                const contributorType = contributorTypes[node.attrs.metadata] || 'other' // TODO: Figure out if 'other' is legal
+                const contributorType = contributorTypes[node.attrs.metadata] || "other" // TODO: Figure out if 'other' is legal
                 start += `<contrib-group content-type="${contributorType}">`
-                end = '</contrib-group>' + end
+                end = "</contrib-group>" + end
                 const contributorTypeId = node.attrs.id
                 let counter = 1
                 node.content.forEach(childNode => {
                     const contributor = childNode.attrs
                     if (contributor.firstname || contributor.lastname) {
                         content += `<contrib id="${contributorTypeId}-${counter++}" contrib-type="person">`
-                        content += '<name>'
+                        content += "<name>"
                         if (contributor.lastname) {
                             content += `<surname>${escapeText(contributor.lastname)}</surname>`
                         }
                         if (contributor.firstname) {
                             content += `<given-names>${escapeText(contributor.firstname)}</given-names>`
                         }
-                        content += '</name>'
+                        content += "</name>"
                         if (contributor.institution) {
                             let affNumber
                             if (this.affiliations[contributor.institution]) {
@@ -286,80 +288,80 @@ export class JATSExporterConvert {
                             }
                             content += `<xref ref-type="aff" rid="aff${affNumber}" />`
                         }
-                        content += '</contrib>'
+                        content += "</contrib>"
                     } else if (contributor.institution) {
                         // There is an affiliation but no first/last name. We take this
                         // as a group collaboration.
                         content += `<contrib id="${contributorTypeId}-${counter++}" contrib-type="group">`
                         content += `<collab><named-content content-type="name">${escapeText(contributor.institution)}</named-content></collab>`
-                        content += '</contrib>'
+                        content += "</contrib>"
                     }
                 })
             }
             break
-        case 'tags_part':
+        case "tags_part":
             if (node.content) {
-                start += `<subj-group subj-group-type="${node.attrs.id}"${ node.attrs.language ? ` xml:lang="${node.attrs.language}"` : ''}>`
-                end = '</subj-group>' + end
+                start += `<subj-group subj-group-type="${node.attrs.id}"${ node.attrs.language ? ` xml:lang="${node.attrs.language}"` : ""}>`
+                end = "</subj-group>" + end
             }
             break
-        case 'keywords':
+        case "keywords":
             if (node.content) {
-                start += `<kwd-group${ node.attrs.language ? ` xml:lang="${node.attrs.language}"` : ''}>`
-                end = '</kwd-group>' + end
+                start += `<kwd-group${ node.attrs.language ? ` xml:lang="${node.attrs.language}"` : ""}>`
+                end = "</kwd-group>" + end
                 options = Object.assign({}, options)
                 options.inKeywords = true
             }
             break
-        case 'tag':
+        case "tag":
             if (options.inKeywords) {
                 content += `<kwd>${node.attrs.tag}</kwd>`
             } else {
                 content += `<subject>${node.attrs.tag}</subject>`
             }
             break
-        case 'abstract':
+        case "abstract":
             if (node.content) {
-                start += `<abstract>`
-                end = '</abstract>' + end
+                start += "<abstract>"
+                end = "</abstract>" + end
             }
             break
-        case 'trans_abstract':
+        case "trans_abstract":
             if (node.content) {
                 start += `<trans-abstract xml:lang="${node.attrs.language}">`
-                end = '</trans-abstract>' + end
+                end = "</trans-abstract>" + end
             }
             break
-        case 'richtext_part':
+        case "richtext_part":
             if (node.attrs.metadata) {
                 options = Object.assign({}, options)
                 options.partMetadata = node.attrs.metadata
             }
             break
-        case 'table_of_contents':
+        case "table_of_contents":
             // TODO: Not sure what to use here.
             break
-        case 'separator_part':
-        case 'table_part':
+        case "separator_part":
+        case "table_part":
             // part separators as in page breaks should usually already be handled
             // by JATS renderer and table parts will simply show the table inside of them.
             break
-        case 'paragraph':
+        case "paragraph":
             start += `<p id="p-${++this.parCounter}">`
-            end = '</p>' + end
+            end = "</p>" + end
             break
-        case 'heading1':
-        case 'heading2':
-        case 'heading3':
-        case 'heading4':
-        case 'heading5':
-        case 'heading6': {
+        case "heading1":
+        case "heading2":
+        case "heading3":
+        case "heading4":
+        case "heading5":
+        case "heading6": {
             if (options.ignoreHeading) {
                 break
             } else if (options.inFootnote) {
                 // only allows <p> block level elements https://jats.nlm.nih.gov/archiving/tag-library/1.2/element/fn.html
                 start += `<p id="p-${++this.parCounter}">`
-                end = '</p>' + end
+                end = "</p>" + end
                 break
             }
             const metadata = options.partMetadata
@@ -374,30 +376,30 @@ export class JATSExporterConvert {
             while (this.currentSectionLevel < level) {
                 this.currentSectionLevel++
                 if (this.currentSectionLevel === level) {
-                    start += `<sec id="${node.attrs.id}"${ metadata ? ` sec-type="${metadata}"` : ''}>`
+                    start += `<sec id="${node.attrs.id}"${ metadata ? ` sec-type="${metadata}"` : ""}>`
                 } else {
                     start += `<sec id="h-${++this.headingCounter}">`
                 }
             }
-            start += '<title>'
-            end = '</title>' + end
+            start += "<title>"
+            end = "</title>" + end
             break
         }
-        case 'code_block':
+        case "code_block":
             if (options.inFootnote) {
                 // only allows <p> block level elements https://jats.nlm.nih.gov/archiving/tag-library/1.2/element/fn.html
                 start += `<p id="p-${++this.parCounter}">`
-                end = '</p>' + end
+                end = "</p>" + end
                 break
             }
-            start += '<code>'
-            end = '</code>' + end
+            start += "<code>"
+            end = "</code>" + end
             break
-        case 'blockquote':
-            start += '<disp-quote>'
-            end = '</disp-quote>' + end
+        case "blockquote":
+            start += "<disp-quote>"
+            end = "</disp-quote>" + end
             break
-        case 'ordered_list': {
+        case "ordered_list": {
             if (options.inFootnote) {
                 // only allows <p> block level elements https://jats.nlm.nih.gov/archiving/tag-library/1.2/element/fn.html
                 break
@@ -420,20 +422,20 @@ export class JATSExporterConvert {
             options = Object.assign({}, options)
             options.inOrderedList = this.listCounter
             this.orderedListLengths[options.inOrderedList] = continuedListEndNumber
-            end = '</list>' + end
+            end = "</list>" + end
             break
         }
-        case 'bullet_list':
+        case "bullet_list":
             if (options.inFootnote) {
                 // only allows <p> block level elements https://jats.nlm.nih.gov/archiving/tag-library/1.2/element/fn.html
                 break
             }
             start += `<list list-type="bullet" id="list-${++this.listCounter}">`
-            end = '</list>' + end
+            end = "</list>" + end
             options = Object.assign({}, options)
             delete options.inOrderedList
             break
-        case 'list_item':
+        case "list_item":
             if (options.inFootnote) {
                 // only allows <p> block level elements https://jats.nlm.nih.gov/archiving/tag-library/1.2/element/fn.html
                 break
@@ -441,15 +443,15 @@ export class JATSExporterConvert {
             if (options.inOrderedList !== undefined) {
                 this.orderedListLengths[options.inOrderedList] += 1
             }
-            start += '<list-item>'
-            end = '</list-item>' + end
+            start += "<list-item>"
+            end = "</list-item>" + end
             break
-        case 'footnote':
+        case "footnote":
             content += `<xref ref-type="fn" rid="fn-${++this.fnCounter}">${this.fnCounter}</xref>`
             options = Object.assign({}, options)
             options.inFootnote = true
             this.footnotes.push(this.walkJson({
-                type: 'footnotecontainer',
+                type: "footnotecontainer",
                 attrs: {
                     id: `fn-${this.fnCounter}`,
                     label: this.fnCounter // Note: it's unclear whether the footnote number is required as a label
@@ -457,55 +459,23 @@ export class JATSExporterConvert {
                 content: node.attrs.footnote
             }, options))
             break
-        case 'footnotecontainer':
+        case "footnotecontainer":
             start += `<fn id="${node.attrs.id}"><label>${node.attrs.label}</label>`
-            end = '</fn>' + end
+            end = "</fn>" + end
             break
-        case 'text': {
-            let strong, em, underline, hyperlink
-            // Check for hyperlink, bold/strong, italic/em and underline
-            if (node.marks) {
-                strong = node.marks.find(mark => mark.type === 'strong')
-                em = node.marks.find(mark => mark.type === 'em')
-                underline = node.marks.find(mark => mark.type === 'underline')
-                hyperlink = node.marks.find(mark => mark.type === 'link')
-            }
-            if (em) {
-                start += '<italic>'
-                end = '</italic>' + end
-            }
-            if (strong) {
-                start += '<bold>'
-                end = '</bold>' + end
-            }
-            if (underline) {
-                start += '<underline>'
-                end = '</underline>' + end
-            }
-            if (hyperlink) {
-                const href = hyperlink.attrs.href
-                if (href[0] === '#') {
-                    // Internal link
-                    start += `<xref rid="${href.substring(1)}">`
-                    end = '</xref>' + end
-                } else {
-                    // External link
-                    start += `<ext-link xlink:href="${href}" ext-link-type="uri" xlink:title="${hyperlink.attrs.title}">`
-                    end = '</ext-link>' + end
-                }
-            }
-            content += escapeText(node.text)
+        case "text": {
+            content += convertText(node)
             break
         }
-        case 'cross_reference': {
+        case "cross_reference": {
             start += `<xref rid="${node.attrs.id}">`
-            content += escapeText(node.attrs.title || 'MISSING TARGET')
-            end = '</xref>' + end
+            content += escapeText(node.attrs.title || "MISSING TARGET")
+            end = "</xref>" + end
             break
         }
-        case 'citation': {
+        case "citation": {
             const citationText = this.exporter.citations.citationTexts[this.citationCount++]
-            if (options.inFootnote || this.exporter.citations.citFm.citationType !== 'note') {
+            if (options.inFootnote || this.exporter.citations.citFm.citationType !== "note") {
                 content += citationText
             } else {
                 content += `<xref ref-type="fn" rid="fn-${++this.fnCounter}">${this.fnCounter}</xref>`
@@ -515,24 +485,24 @@ export class JATSExporterConvert {
             }
             break
         }
-        case 'figure': {
+        case "figure": {
             // Note: width and alignment are not stored due to lack of corresponding attributes in JATS.
             if (options.inFootnote) {
                 // only allows <p> block level elements https://jats.nlm.nih.gov/archiving/tag-library/1.2/element/fn.html
                 break
             }
             let imageFilename, copyright
-            const image = node.content.find(node => node.type === 'image')?.attrs.image || false
+            const image = node.content.find(node => node.type === "image")?.attrs.image || false
             if (image !== false) {
                 this.imageIds.push(image)
                 const imageDBEntry = this.imageDB.db[image],
                     filePathName = imageDBEntry.image
                 copyright = imageDBEntry.copyright
-                imageFilename = filePathName.split('/').pop()
+                imageFilename = filePathName.split("/").pop()
             }
-            const caption = node.attrs.caption ? node.content.find(node => node.type === 'figure_caption')?.content || [] : []
+            const caption = node.attrs.caption ? node.content.find(node => node.type === "figure_caption")?.content || [] : []
             if (
-                node.attrs.category === 'none' &&
+                node.attrs.category === "none" &&
                     imageFilename &&
                     !caption.length &&
                     (!copyright || !copyright.holder)
@@ -540,10 +510,10 @@ export class JATSExporterConvert {
                 content += `<graphic id="${node.attrs.id}" position="anchor" xlink:href="${imageFilename}"/>`
             } else {
                 start += `<fig id="${node.attrs.id}">`
-                end = '</fig>' + end
+                end = "</fig>" + end
 
                 const category = node.attrs.category
-                if (category !== 'none') {
+                if (category !== "none") {
                     if (!this.categoryCounter[category]) {
                         this.categoryCounter[category] = 0
                     }
@@ -552,26 +522,26 @@ export class JATSExporterConvert {
                     start += `<label>${escapeText(catLabel)}</label>`
                 }
                 if (caption.length) {
-                    start += `<caption><p>${caption.map(node => this.walkJson(node)).join('')}</p></caption>`
+                    start += `<caption><p>${caption.map(node => this.walkJson(node)).join("")}</p></caption>`
                 }
-                const equation = node.content.find(node => node.type === 'figure_equation')?.attrs.equation
+                const equation = node.content.find(node => node.type === "figure_equation")?.attrs.equation
                 if (equation) {
-                    start += '<disp-formula>'
-                    end = '</disp-formula>' + end
+                    start += "<disp-formula>"
+                    end = "</disp-formula>" + end
                     content = `<tex-math><![CDATA[${equation}]]></tex-math>`
                 } else {
                     if (copyright?.holder) {
-                        start += '<permissions>'
+                        start += "<permissions>"
                         const year = copyright.year ? copyright.year : new Date().getFullYear()
                         start += `<copyright-year>${year}</copyright-year>`
                         start += `<copyright-holder>${escapeText(copyright.holder)}</copyright-holder>`
                         if (copyright.freeToRead) {
-                            start += '<ali:free_to_read/>'
+                            start += "<ali:free_to_read/>"
                         }
                         start += copyright.licenses.map(license =>
-                            `<license><ali:license_ref${license.start ? ` start_date="${license.start}"` : ''}>${escapeText(license.url)}</ali:license_ref></license>`
-                        ).join('')
-                        start += '</permissions>'
+                            `<license><ali:license_ref${license.start ? ` start_date="${license.start}"` : ""}>${escapeText(license.url)}</ali:license_ref></license>`
+                        ).join("")
+                        start += "</permissions>"
                     }
                     if (imageFilename) {
                         content += `<graphic position="anchor" xlink:href="${imageFilename}"/>`
@@ -580,25 +550,25 @@ export class JATSExporterConvert {
             }
             break
         }
-        case 'figure_caption':
+        case "figure_caption":
             // We are already dealing with this in the figure. Prevent content from being added a second time.
-            return ''
-        case 'figure_equation':
+            return ""
+        case "figure_equation":
             // We are already dealing with this in the figure.
             break
-        case 'image':
+        case "image":
             // We are already dealing with this in the figure.
             break
-        case 'table': {
+        case "table": {
             // Note: We ignore right/left/center aligned and table layout
             if (options.inFootnote) {
                 // only allows <p> block level elements https://jats.nlm.nih.gov/archiving/tag-library/1.2/element/fn.html
                 break
             }
-            start += '<table-wrap>'
-            end = '</table-wrap>' + end
+            start += "<table-wrap>"
+            end = "</table-wrap>" + end
             const category = node.attrs.category
-            if (category !== 'none') {
+            if (category !== "none") {
                 if (!this.categoryCounter[category]) {
                     this.categoryCounter[category] = 0
                 }
@@ -608,41 +578,41 @@ export class JATSExporterConvert {
             }
             const caption = node.attrs.caption ? node.content[0].content || [] : []
             if (caption.length) {
-                start += `<caption><p>${caption.map(node => this.walkJson(node)).join('')}</p></caption>`
+                start += `<caption><p>${caption.map(node => this.walkJson(node)).join("")}</p></caption>`
             }
             start += `<table width="${node.attrs.width}%"><tbody>`
-            end = `</tbody></table>` + end
+            end = "</tbody></table>" + end
             break
         }
-        case 'table_body':
+        case "table_body":
             // Pass through to table.
             break
-        case 'table_caption':
+        case "table_caption":
             // We already deal with this in 'table'.
-            return ''
-        case 'table_row':
-            start += '<tr>'
-            end = '</tr>' + end
+            return ""
+        case "table_row":
+            start += "<tr>"
+            end = "</tr>" + end
             break
-        case 'table_cell':
-            start += `<td${node.attrs.colspan === 1 ? '' : ` colspan="${node.attrs.colspan}"`}${node.attrs.rowspan === 1 ? '' : ` rowspan="${node.attrs.rowspan}"`}>`
-            end = '</td>' + end
+        case "table_cell":
+            start += `<td${node.attrs.colspan === 1 ? "" : ` colspan="${node.attrs.colspan}"`}${node.attrs.rowspan === 1 ? "" : ` rowspan="${node.attrs.rowspan}"`}>`
+            end = "</td>" + end
             break
-        case 'table_header':
-            start += `<th${node.attrs.colspan === 1 ? '' : ` colspan="${node.attrs.colspan}"`}${node.attrs.rowspan === 1 ? '' : ` rowspan="${node.attrs.rowspan}"`}>`
-            end = '</th>' + end
+        case "table_header":
+            start += `<th${node.attrs.colspan === 1 ? "" : ` colspan="${node.attrs.colspan}"`}${node.attrs.rowspan === 1 ? "" : ` rowspan="${node.attrs.rowspan}"`}>`
+            end = "</th>" + end
             break
-        case 'equation':
-            start += '<inline-formula>'
-            end = '</inline-formula>' + end
+        case "equation":
+            start += "<inline-formula>"
+            end = "</inline-formula>" + end
             content = `<tex-math><![CDATA[${node.attrs.equation}]]></tex-math>`
             break
-        case 'hard_break':
+        case "hard_break":
             // Apparently forbidden inside of <p> and a number of
             // other elements, but not inside of <bold>, which is
             // why we add that.
             // https://jats.nlm.nih.gov/archiving/tag-library/1.2/element/break.html
-            content += '<bold><break /></bold>'
+            content += "<bold><break /></bold>"
             break
         default:
             break
@@ -658,9 +628,9 @@ export class JATSExporterConvert {
     }
 
     closeSections(targetLevel) {
-        let returnValue = ''
+        let returnValue = ""
         while (this.currentSectionLevel > targetLevel) {
-            returnValue += '</sec>'
+            returnValue += "</sec>"
             this.currentSectionLevel--
         }
 
@@ -672,14 +642,14 @@ export class JATSExporterConvert {
     }
 
     assembleBack() {
-        let back = '<back>'
+        let back = "<back>"
         if (this.footnotes.length) {
-            back += `<fn-group>${this.footnotes.join('')}</fn-group>`
+            back += `<fn-group>${this.footnotes.join("")}</fn-group>`
         }
         if (this.exporter.citations.jatsBib.length) {
             back += `<ref-list>${this.exporter.citations.jatsBib}</ref-list>`
         }
-        back += '</back>'
+        back += "</back>"
         return back
     }
 
