@@ -21,15 +21,15 @@ export class OdtExporterMath {
     }
 
     checkObjectCounter() {
-        const manifestEl = this.manifestXml.querySelector('manifest')
-        const fileEntries = manifestEl.querySelectorAll('file-entry')
+        const manifestEl = this.manifestXml.querySelector("manifest")
+        const fileEntries = manifestEl.querySelectorAll("file-entry")
 
         fileEntries.forEach(
             fileEntry => {
-                const fullPath = fileEntry.getAttribute('manifest:full-path')
-                const dir = fullPath.split('/')[0]
-                const dirParts = dir.split(' ')
-                if (dirParts.length === 2 && dirParts[0] === 'Object') {
+                const fullPath = fileEntry.getAttribute("manifest:full-path")
+                const dir = fullPath.split("/")[0]
+                const dirParts = dir.split(" ")
+                if (dirParts.length === 2 && dirParts[0] === "Object") {
                     const objectNumber =  parseInt(dirParts[1])
                     if (objectNumber >= this.objectCounter) {
                         this.objectCounter = objectNumber + 1
@@ -41,11 +41,11 @@ export class OdtExporterMath {
 
     latexToMathML(latex) {
         return this.mathLive.convertLatexToMathMl(latex)
-            .replace(/&InvisibleTimes;/g, '&#8290;')
-            .replace(/&ApplyFunction;/g, '&#x2061;')
-            .replace(/&PlusMinus;/g, '&#177;')
-            .replace(/&times;/g, '&#215;')
-            .replace(/&x2061;/g, '&#x2061;') // Bug in mathlive 0.59. Has been fixed since.
+            .replace(/&InvisibleTimes;/g, "&#8290;")
+            .replace(/&ApplyFunction;/g, "&#x2061;")
+            .replace(/&PlusMinus;/g, "&#177;")
+            .replace(/&times;/g, "&#215;")
+            .replace(/&x2061;/g, "&#x2061;") // Bug in mathlive 0.59. Has been fixed since.
     }
 
     addMath(latex) {
@@ -56,11 +56,11 @@ export class OdtExporterMath {
                 this.latexToMathML(latex)
             }</math>`
         )
-        const manifestEl = this.manifestXml.querySelector('manifest')
+        const manifestEl = this.manifestXml.querySelector("manifest")
         const stringOne = `<manifest:file-entry manifest:full-path="Object ${objectNumber}/content.xml" manifest:media-type="text/xml"/>`
-        manifestEl.insertAdjacentHTML('beforeEnd', stringOne)
+        manifestEl.insertAdjacentHTML("beforeEnd", stringOne)
         const stringTwo = `<manifest:file-entry manifest:full-path="Object ${objectNumber}/" manifest:version="1.2" manifest:media-type="application/vnd.oasis.opendocument.formula"/>`
-        manifestEl.insertAdjacentHTML('beforeEnd', stringTwo)
+        manifestEl.insertAdjacentHTML("beforeEnd", stringTwo)
         return objectNumber
     }
 
