@@ -12,7 +12,7 @@ export class PrintExporter extends HTMLExporter {
             `a.fn {
                 -adapt-template: url(data:application/xml,${
     encodeURI(
-        '<html xmlns="http://www.w3.org/1999/xhtml" xmlns:s="http://www.pyroxy.com/ns/shadow"><head><style>.footnote-content{float:footnote}</style></head><body><s:template id="footnote"><s:content/><s:include class="footnote-content"/></s:template></body></html>#footnote'
+        "<html xmlns=\"http://www.w3.org/1999/xhtml\" xmlns:s=\"http://www.pyroxy.com/ns/shadow\"><head><style>.footnote-content{float:footnote}</style></head><body><s:template id=\"footnote\"><s:content/><s:include class=\"footnote-content\"/></s:template></body></html>#footnote"
     )
 });
                 text-decoration: none;
@@ -90,7 +90,7 @@ export class PrintExporter extends HTMLExporter {
     }
 
     init() {
-        addAlert('info', `${shortFileTitle(this.doc.title, this.doc.path)}: ${gettext('Printing has been initiated.')}`)
+        addAlert("info", `${shortFileTitle(this.doc.title, this.doc.path)}: ${gettext("Printing has been initiated.")}`)
         this.docContent = removeHidden(this.doc.content, false)
         this.addDocStyle(this.doc)
 
@@ -104,17 +104,17 @@ export class PrintExporter extends HTMLExporter {
             ({html, title}) => {
                 const config = {title}
 
-                if (navigator.userAgent.includes('Gecko/')) {
+                if (navigator.userAgent.includes("Gecko/")) {
                     // Firefox has issues printing images when in iframe. This workaround can be
                     // removed once that has been fixed. TODO: Add gecko bug number if there is one.
                     config.printCallback = iframeWin => {
                         const oldBody = document.body
                         document.body.parentElement.dataset.vivliostylePaginated = true
                         document.body = iframeWin.document.body
-                        document.body.querySelectorAll('figure, table').forEach(el => delete el.dataset.category)
-                        iframeWin.document.querySelectorAll('style').forEach(el => document.body.appendChild(el))
-                        const backgroundStyle = document.createElement('style')
-                        backgroundStyle.innerHTML = 'body {background-color: white;}'
+                        document.body.querySelectorAll("figure, table").forEach(el => delete el.dataset.category)
+                        iframeWin.document.querySelectorAll("style").forEach(el => document.body.appendChild(el))
+                        const backgroundStyle = document.createElement("style")
+                        backgroundStyle.innerHTML = "body {background-color: white;}"
                         document.body.appendChild(backgroundStyle)
                         window.print()
                         document.body = oldBody
@@ -139,7 +139,7 @@ export class PrintExporter extends HTMLExporter {
         let contents = docStyle.contents
         docStyle.documentstylefile_set.forEach(
             ([url, filename]) => contents = contents.replace(
-                new RegExp(filename, 'g'),
+                new RegExp(filename, "g"),
                 url
             )
         )
@@ -158,7 +158,7 @@ export class PrintExporter extends HTMLExporter {
     }
 
     addMathliveStylesheet() {
-        this.styleSheets.push({url: `${settings_STATIC_URL}css/libs/mathlive/mathlive.css?v=${transpile_VERSION}`})
+        this.styleSheets.push({url: staticUrl("css/libs/mathlive/mathlive.css")})
     }
 
     getFootnoteAnchor(counter) {
