@@ -25,7 +25,7 @@ export class DOMExporter {
         this.fontFiles = []
         this.binaryFiles = []
         this.styleSheets = [
-            {url: `${settings_STATIC_URL}css/document.css?v=${transpile_VERSION}`}
+            {url: staticUrl("css/document.css")}
         ]
     }
 
@@ -40,7 +40,7 @@ export class DOMExporter {
         let contents = docStyle.contents
         docStyle.documentstylefile_set.forEach(
             ([_url, filename]) => contents = contents.replace(
-                new RegExp(filename, 'g'),
+                new RegExp(filename, "g"),
                 `media/${filename}`
             )
         )
@@ -61,7 +61,7 @@ export class DOMExporter {
                     ).then(
                         response => {
                             sheet.contents = response
-                            sheet.filename = `css/${sheet.url.split('/').pop().split('?')[0]}`
+                            sheet.filename = `css/${sheet.url.split("/").pop().split("?")[0]}`
                             delete sheet.url
                         }
                     )
@@ -96,18 +96,18 @@ export class DOMExporter {
     }
 
     addCategoryLabels(language) {
-        this.content.querySelectorAll('figcaption span.label,caption span.label').forEach(el => {
+        this.content.querySelectorAll("figcaption span.label,caption span.label").forEach(el => {
             const category = el.parentElement.parentElement.dataset.category
-            el.innerHTML = category === 'none' ? '' : CATS[category][language]
+            el.innerHTML = category === "none" ? "" : CATS[category][language]
         })
     }
 
     addBibliographyHTML(bibliographyHTML) {
         if (bibliographyHTML.length > 0) {
-            const tempNode = document.createElement('div')
+            const tempNode = document.createElement("div")
             tempNode.innerHTML = bibliographyHTML
             while (tempNode.firstChild) {
-                const footnotesContainer = this.content.querySelector('section.fnlist')
+                const footnotesContainer = this.content.querySelector("section.fnlist")
                 this.content.insertBefore(tempNode.firstChild, footnotesContainer)
             }
         }
@@ -124,13 +124,13 @@ export class DOMExporter {
         if (node.nodeType === 1) {
             [].forEach.call(node.childNodes, child => this.replaceText(child, before, after))
         } else if (node.nodeType === 3) {
-            node.textContent = node.textContent.replace(window.RegExp(before, 'g'), after)
+            node.textContent = node.textContent.replace(window.RegExp(before, "g"), after)
         }
     }
 
     cleanNode(node) {
-        if (node.contentEditable === 'true') {
-            node.removeAttribute('contentEditable')
+        if (node.contentEditable === "true") {
+            node.removeAttribute("contentEditable")
         }
         if (node.children) {
             Array.from(node.children).forEach(childNode => this.cleanNode(childNode))
@@ -138,10 +138,10 @@ export class DOMExporter {
     }
 
     getFootnoteAnchor(counter) {
-        const footnoteAnchor = document.createElement('a')
-        footnoteAnchor.setAttribute('href', '#fn' + counter)
+        const footnoteAnchor = document.createElement("a")
+        footnoteAnchor.setAttribute("href", "#fn" + counter)
         // RASH 0.5 doesn't mark the footnote anchors, so we add this class
-        footnoteAnchor.classList.add('fn')
+        footnoteAnchor.classList.add("fn")
         return footnoteAnchor
     }
 
@@ -150,19 +150,19 @@ export class DOMExporter {
         // at the back of the document.
         // Also, link the footnote anchor with the footnote according to
         // https://rawgit.com/essepuntato/rash/master/documentation/index.html#footnotes.
-        const footnotes = this.content.querySelectorAll('.footnote-marker')
-        const footnotesContainer = document.createElement('section')
-        footnotesContainer.classList.add('fnlist')
-        footnotesContainer.setAttribute('role', 'doc-footnotes')
+        const footnotes = this.content.querySelectorAll(".footnote-marker")
+        const footnotesContainer = document.createElement("section")
+        footnotesContainer.classList.add("fnlist")
+        footnotesContainer.setAttribute("role", "doc-footnotes")
 
         footnotes.forEach(
             (footnote, index) => {
                 const counter = index + 1
                 const footnoteAnchor = this.getFootnoteAnchor(counter)
                 footnote.parentNode.replaceChild(footnoteAnchor, footnote)
-                const newFootnote = document.createElement('section')
-                newFootnote.id = 'fn' + counter
-                newFootnote.setAttribute('role', 'doc-footnote')
+                const newFootnote = document.createElement("section")
+                newFootnote.id = "fn" + counter
+                newFootnote.setAttribute("role", "doc-footnote")
                 newFootnote.innerHTML = footnote.dataset.footnote
                 footnotesContainer.appendChild(newFootnote)
             }
@@ -171,9 +171,9 @@ export class DOMExporter {
     }
 
     moveCitationFootnotes(citationFormatter) {
-        const footnotes = this.content.querySelectorAll('a.fn, .citation')
-        const footnotesContainer = this.content.querySelector('section.fnlist')
-        const fnCountOffset = this.content.querySelectorAll('a.fn').length
+        const footnotes = this.content.querySelectorAll("a.fn, .citation")
+        const footnotesContainer = this.content.querySelector("section.fnlist")
+        const fnCountOffset = this.content.querySelectorAll("a.fn").length
 
         if (footnotes.length === fnCountOffset) {
             // There are no citations to move
@@ -184,23 +184,22 @@ export class DOMExporter {
 
         footnotes.forEach(
             (footnote, index) => {
-                if (footnote.matches('a.fn')) {
+                if (footnote.matches("a.fn")) {
                     // Regular footnote - skip
                     return
                 }
-                if (footnote.matches('section.fnlist .citation')) {
+                if (footnote.matches("section.fnlist .citation")) {
                     // The citation is already in a footnote. Do not add a second footnote.
-                    footnote.innerHTML = `<p><span class="citation">${citationFormatter.citationTexts[
-                        counter
-                    ] || " "}</span></p>`
+                    footnote.innerHTML = citationFormatter.citationTexts[counter] || " "
+                    counter += 1
                     return
                 }
                 const id = fnCountOffset + counter + 1
                 const footnoteAnchor = this.getFootnoteAnchor(id)
                 footnote.parentNode.replaceChild(footnoteAnchor, footnote)
-                const newFootnote = document.createElement('section')
-                newFootnote.id = 'fn' + (id)
-                newFootnote.setAttribute('role', 'doc-footnote')
+                const newFootnote = document.createElement("section")
+                newFootnote.id = "fn" + (id)
+                newFootnote.setAttribute("role", "doc-footnote")
                 newFootnote.innerHTML = `<p><span class="citation">${citationFormatter.citationTexts[
                     counter
                 ] || " "}</span></p>`
@@ -213,59 +212,59 @@ export class DOMExporter {
     }
 
     cleanHTML(citationFormatter) {
-        if (citationFormatter.citationType === 'note') {
+        if (citationFormatter.citationType === "note") {
             this.moveCitationFootnotes(citationFormatter)
         }
 
         this.cleanNode(this.content)
 
         // Replace nbsp spaces with normal ones
-        this.replaceText(this.content, '&nbsp;', ' ')
+        this.replaceText(this.content, "&nbsp;", " ")
 
-        this.content.querySelectorAll('.comment').forEach(el => {
+        this.content.querySelectorAll(".comment").forEach(el => {
             el.insertAdjacentHTML(
-                'afterend',
+                "afterend",
                 el.innerHTML
             )
             el.parentElement.removeChild(el)
         })
 
-        this.content.querySelectorAll('.citation').forEach(el => {
+        this.content.querySelectorAll(".citation").forEach(el => {
             delete el.dataset.references
             delete el.dataset.bibs
             delete el.dataset.format
         })
-        this.content.querySelectorAll('img').forEach(el => {
+        this.content.querySelectorAll("img").forEach(el => {
             delete el.dataset.image
             delete el.dataset.imageSrc
         })
 
-        this.content.querySelectorAll('table').forEach(el => {
+        this.content.querySelectorAll("table").forEach(el => {
             delete el.dataset.captionHidden
         })
 
-        this.content.querySelectorAll('figcaption span.text:empty,caption span.text:empty').forEach(el => {
+        this.content.querySelectorAll("figcaption span.text:empty,caption span.text:empty").forEach(el => {
             el.parentElement.removeChild(el)
         })
 
-        this.content.querySelectorAll('.cross-reference').forEach(el => {
+        this.content.querySelectorAll(".cross-reference").forEach(el => {
             el.innerHTML = `<a href="#${el.dataset.id}">${el.innerHTML}</a>`
         })
     }
 
     // Fill the contents of table of contents.
     fillToc() {
-        const headlines = Array.from(this.content.querySelectorAll('h1,h2,h3,h4,h5,h6'))
-        const tocs = Array.from(this.content.querySelectorAll('div.table-of-contents'))
+        const headlines = Array.from(this.content.querySelectorAll("h1,h2,h3,h4,h5,h6"))
+        const tocs = Array.from(this.content.querySelectorAll("div.table-of-contents"))
         tocs.forEach(toc => {
             toc.innerHTML += headlines.map(headline => {
                 if (!headline.id || !headline.textContent.length) {
                     // ignore the tocs own headlines
-                    return ''
+                    return ""
                 }
                 const tagName = headline.tagName.toLowerCase()
                 return `<${tagName}><a href="#${headline.id}">${headline.innerHTML}</a></${tagName}>`
-            }).join('')
+            }).join("")
         })
     }
 }
