@@ -43,9 +43,6 @@ class EditorTest(LiveTornadoTestCase, SeleniumHelper):
             username="Yeti", email="yeti@snowman.com", passtext="otter"
         )
 
-    def tearDown(self):
-        self.leave_site(self.driver)
-
     def test_crossrefs_and_internal_links(self):
         self.driver.get(self.base_url)
         self.driver.find_element(By.ID, "id-login").send_keys("Yeti")
