@@ -37,9 +37,6 @@ class PathTest(LiveTornadoTestCase, SeleniumHelper):
             username="Yeti", email="yeti@snowman.com", passtext="otter"
         )
 
-    def tearDown(self):
-        self.leave_site(self.driver)
-
     def test_move_document(self):
         self.driver.get(self.base_url)
         self.driver.find_element(By.ID, "id-login").send_keys("Yeti")
