@@ -4,13 +4,13 @@ export const headerNavTemplate = ({navItems}) =>
     navItems.map(navItem =>
         `<p class="fw-nav-item ${
             navItem.active ?
-                'active-menu-wrapper' :
-                ''
+                "active-menu-wrapper" :
+                ""
         }">
                 <a class="fw-header-navigation-text" href="${navItem.url}" title="${navItem.title}">
                     ${navItem.text}
                 </a>
             </p>`
-    ).join('')
+    ).join("")
 }
     </div>`
