@@ -14,7 +14,7 @@ export class DocTemplatesEditor {
         ensureCSS([
             staticUrl("css/errorlist.css"),
             staticUrl("css/editor.css"),
-            staticUrl("user_template_manager.css")
+            staticUrl("css/user_template_manager.css")
         ])
         return this.app.csl.getStyles().then(
             styles => {
