@@ -3,7 +3,7 @@ from django.db import migrations, models, transaction
 
 
 def text_to_json(apps, schema_editor):
-    UserImage = apps.get_model('usermedia', 'UserImage')
+    UserImage = apps.get_model("usermedia", "UserImage")
     uimages = UserImage.objects.all().iterator()
     with transaction.atomic():
         for image in uimages:
@@ -18,10 +18,10 @@ def text_to_json(apps, schema_editor):
                     "holder": False,
                     "year": False,
                     "freeToRead": True,
-                    "licenses": []
+                    "licenses": [],
                 }
             image.save()
-    DocumentImage = apps.get_model('usermedia', 'DocumentImage')
+    DocumentImage = apps.get_model("usermedia", "DocumentImage")
     dimages = DocumentImage.objects.all().iterator()
     with transaction.atomic():
         for image in dimages:
@@ -32,19 +32,20 @@ def text_to_json(apps, schema_editor):
                     "holder": False,
                     "year": False,
                     "freeToRead": True,
-                    "licenses": []
+                    "licenses": [],
                 }
             image.save()
 
+
 def json_to_text(apps, schema_editor):
-    UserImage = apps.get_model('usermedia', 'UserImage')
+    UserImage = apps.get_model("usermedia", "UserImage")
     images = UserImage.objects.all().iterator()
     with transaction.atomic():
         for image in images:
             image.image_cat = json.dumps(image.cats)
             image.copyright_text = json.dumps(image.copyright)
             image.save()
-    DocumentImage = apps.get_model('usermedia', 'DocumentImage')
+    DocumentImage = apps.get_model("usermedia", "DocumentImage")
     dimages = DocumentImage.objects.all().iterator()
     with transaction.atomic():
         for image in dimages:
@@ -55,46 +56,46 @@ def json_to_text(apps, schema_editor):
 class Migration(migrations.Migration):
     atomic = False  # to prevent migrations running in single transaction
     dependencies = [
-        ('usermedia', '0004_auto_20200205_2347'),
+        ("usermedia", "0004_auto_20200205_2347"),
     ]
 
     operations = [
         migrations.AddField(
-            model_name='userimage',
-            name='cats',
+            model_name="userimage",
+            name="cats",
             field=models.JSONField(default=list),
         ),
         migrations.RenameField(
-            model_name='userimage',
-            old_name='copyright',
-            new_name='copyright_text'
+            model_name="userimage",
+            old_name="copyright",
+            new_name="copyright_text",
         ),
         migrations.AddField(
-            model_name='userimage',
-            name='copyright',
+            model_name="userimage",
+            name="copyright",
             field=models.JSONField(default=dict),
         ),
         migrations.RenameField(
-            model_name='documentimage',
-            old_name='copyright',
-            new_name='copyright_text'
+            model_name="documentimage",
+            old_name="copyright",
+            new_name="copyright_text",
         ),
         migrations.AddField(
-            model_name='documentimage',
-            name='copyright',
+            model_name="documentimage",
+            name="copyright",
             field=models.JSONField(default=dict),
         ),
         migrations.RunPython(text_to_json, json_to_text),
         migrations.RemoveField(
-            model_name='userimage',
-            name='image_cat',
+            model_name="userimage",
+            name="image_cat",
         ),
         migrations.RemoveField(
-            model_name='userimage',
-            name='copyright_text',
+            model_name="userimage",
+            name="copyright_text",
         ),
         migrations.RemoveField(
-            model_name='documentimage',
-            name='copyright_text',
+            model_name="documentimage",
+            name="copyright_text",
         ),
     ]
